.. _developers:

Development
===========

.. note::

   If you are new to aeon, it may be helpful to take a look at the
   :ref:`get_involved` page first.

.. toctree::
   :maxdepth: 1
   :hidden:

   developer_guide
   reviewer_guide
   enhancement_proposals
   roadmap
   governance

.. grid:: 1 2 2 2
    :gutter: 3

    .. grid-item-card::
        :text-align: center

        Developer Guide

        ^^^

        Learn our development conventions.

        +++

        .. button-ref:: developer_guide
            :color: primary
            :click-parent:
            :expand:

            Developer Guide

    .. grid-item-card::
        :text-align: center

        Reviewer Guide

        ^^^

        How we review contributions.

        +++

        .. button-ref:: reviewer_guide
            :color: primary
            :click-parent:
            :expand:

            Reviewer Guide

    .. grid-item-card::
        :text-align: center

        Enhancement Proposals

        ^^^

        Thought of a project enhancement? See when and how to submit a proposal.

        +++

        .. button-ref:: enhancement_proposals
            :color: primary
            :click-parent:
            :expand:

            Enhancement Proposals

    .. grid-item-card::
        :text-align: center

        Roadmap

        ^^^

        What's on the development horizon?

        +++

        .. button-ref:: roadmap
            :color: primary
            :click-parent:
            :expand:

            Roadmap

    .. grid-item-card::
        :text-align: center

        Governance

        ^^^

        How ``aeon`` is run.

        +++

        .. button-ref:: governance
            :color: primary
            :click-parent:
            :expand:

            Governance
